rnalysis.filtering.HTCountFilter
================================

.. currentmodule:: rnalysis.filtering

.. autoclass:: HTCountFilter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
    :toctree:

      ~HTCountFilter.__init__
      ~HTCountFilter.clustergram
      ~HTCountFilter.describe
      ~HTCountFilter.features_set
      ~HTCountFilter.features_string
      ~HTCountFilter.filter_biotype
      ~HTCountFilter.filter_by_bigtable_group
      ~HTCountFilter.filter_low_reads
      ~HTCountFilter.filter_percentile
      ~HTCountFilter.from_folder
      ~HTCountFilter.head
      ~HTCountFilter.norm_reads_to_rpm
      ~HTCountFilter.norm_reads_with_size_factor
      ~HTCountFilter.pairplot
      ~HTCountFilter.pca
      ~HTCountFilter.save_csv
      ~HTCountFilter.scatter_sample_vs_sample
      ~HTCountFilter.split_by_bigtable_group
      ~HTCountFilter.split_by_percentile
      ~HTCountFilter.split_by_reads
      ~HTCountFilter.violin_plot
   
   

   
   
